;; Generated package description from spacious-padding.el  -*- no-byte-compile: t -*-
(define-package "spacious-padding" "0.4.1.0.20240429.64011" "Increase the padding/spacing of frames and windows" '((emacs "28.1")) :commit "af8030e75e7106e5af6ba481207de6506f23bab2" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("convenience" "focus" "writing" "presentation") :url "https://github.com/protesilaos/spacious-padding")
